##  Overview
Workspace views offer a filtered perspective of workspace data, helping users focus on relevant information and achieve their goals more efficiently. They act like custom filters across dashboards, fact sheets, reports, and diagrams. This reduces distractions from large data volumes and keeps users focused on their tasks. For additional information, see [Workspace Views](https://help.sap.com/docs/leanix/ea/workspace-views?locale=en-US&state=PRODUCTION&version=CLOUD "Use workspace views configured by admins to limit the scope of displayed information and focus on your current tasks.") in the user guide.
As an admin, you can configure up to 20 workspace views, defining which data to include in each. You can also restrict views to specific user roles and define a default view for each role.
![Selecting a Workspace View](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2754b6e87a44101488cf86bbdf0d065d_LowRes.png)
Selecting a Workspace View
